@@ -31,13 +31,12 @@
 #include <libtorrent/add_torrent_params.hpp>
 
 #include <QString>
+#include <QUrl>
 #include <QVector>
 
 #include "infohash.h"
 #include "trackerentry.h"
 
-class QUrl;
-
 namespace BitTorrent
 {
     class MagnetUri
@@ -46,7 +45,7 @@ namespace BitTorrent
         explicit MagnetUri(const QString &source = {});
 
         bool isValid() const;
-        InfoHash hash() const;
+        InfoHash infoHash() const;
         QString name() const;
         QVector<TrackerEntry> trackers() const;
         QVector<QUrl> urlSeeds() const;
@@ -55,12 +54,14 @@ namespace BitTorrent
         lt::add_torrent_params addTorrentParams() const;
 
     private:
-        bool m_valid;
+        bool m_valid = false;
         QString m_url;
-        InfoHash m_hash;
+        InfoHash m_infoHash;
         QString m_name;
         QVector<TrackerEntry> m_trackers;
         QVector<QUrl> m_urlSeeds;
         lt::add_torrent_params m_addTorrentParams;
     };
 }
+
+Q_DECLARE_METATYPE(BitTorrent::MagnetUri)
