@@ -1,6 +1,6 @@
 /*
  * Bittorrent Client using Qt and libtorrent.
- * Copyright (C) 2015  Vladimir Golovnev <glassez@yandex.ru>
+ * Copyright (C) 2015-2023  Vladimir Golovnev <glassez@yandex.ru>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
 
 #include <libtorrent/create_torrent.hpp>
 #include <libtorrent/error_code.hpp>
+#include <libtorrent/version.hpp>
 
 #include <QByteArray>
 #include <QDateTime>
@@ -38,9 +39,10 @@
 #include <QString>
 #include <QStringList>
 #include <QUrl>
-#include <QVector>
 
 #include "base/global.h"
+#include "base/path.h"
+#include "base/preferences.h"
 #include "base/utils/fs.h"
 #include "base/utils/io.h"
 #include "base/utils/misc.h"
@@ -65,12 +67,6 @@ TorrentInfo::TorrentInfo(const lt::torrent_info &nativeInfo)
     }
 }
 
-TorrentInfo::TorrentInfo(const TorrentInfo &other)
-    : m_nativeInfo {other.m_nativeInfo}
-    , m_nativeIndexes {other.m_nativeIndexes}
-{
-}
-
 TorrentInfo &TorrentInfo::operator=(const TorrentInfo &other)
 {
     if (this != &other)
@@ -90,50 +86,42 @@ nonstd::expected<TorrentInfo, QString> TorrentInfo::load(const QByteArray &data)
 {
     // 2-step construction to overcome default limits of `depth_limit` & `token_limit` which are
     // used in `torrent_info()` constructor
-    const int depthLimit = 100;
-    const int tokenLimit = 10000000;
+    const auto *pref = Preferences::instance();
 
     lt::error_code ec;
     const lt::bdecode_node node = lt::bdecode(data, ec
-        , nullptr, depthLimit, tokenLimit);
+            , nullptr, pref->getBdecodeDepthLimit(), pref->getBdecodeTokenLimit());
     if (ec)
         return nonstd::make_unexpected(QString::fromStdString(ec.message()));
 
-    lt::torrent_info nativeInfo {node, ec};
+    const lt::torrent_info nativeInfo {node, ec};
     if (ec)
         return nonstd::make_unexpected(QString::fromStdString(ec.message()));
 
     return TorrentInfo(nativeInfo);
 }
 
-nonstd::expected<TorrentInfo, QString> TorrentInfo::loadFromFile(const QString &path) noexcept
+nonstd::expected<TorrentInfo, QString> TorrentInfo::loadFromFile(const Path &path) noexcept
 {
-    QFile file {path};
-    if (!file.open(QIODevice::ReadOnly))
-        return nonstd::make_unexpected(file.errorString());
-
-    if (file.size() > MAX_TORRENT_SIZE)
-        return nonstd::make_unexpected(tr("File size exceeds max limit %1").arg(Utils::Misc::friendlyUnit(MAX_TORRENT_SIZE)));
-
     QByteArray data;
     try
     {
-        data = file.readAll();
+        const qint64 torrentSizeLimit = Preferences::instance()->getTorrentFileSizeLimit();
+        const auto readResult = Utils::IO::readFile(path, torrentSizeLimit);
+        if (!readResult)
+            return nonstd::make_unexpected(readResult.error().message);
+        data = readResult.value();
     }
     catch (const std::bad_alloc &e)
     {
-        return nonstd::make_unexpected(tr("Torrent file read error: %1").arg(e.what()));
+        return nonstd::make_unexpected(tr("Failed to allocate memory when reading file. File: \"%1\". Error: \"%2\"")
+            .arg(path.toString(), QString::fromLocal8Bit(e.what())));
     }
 
-    if (data.size() != file.size())
-        return nonstd::make_unexpected(tr("Torrent file read error: size mismatch"));
-
-    file.close();
-
     return load(data);
 }
 
-nonstd::expected<void, QString> TorrentInfo::saveToFile(const QString &path) const
+nonstd::expected<void, QString> TorrentInfo::saveToFile(const Path &path) const
 {
     if (!isValid())
         return nonstd::make_unexpected(tr("Invalid metadata"));
@@ -236,17 +224,21 @@ int TorrentInfo::piecesCount() const
     return m_nativeInfo->num_pieces();
 }
 
-QString TorrentInfo::filePath(const int index) const
+Path TorrentInfo::filePath(const int index) const
 {
     if (!isValid()) return {};
 
-    return Utils::Fs::toUniformPath(
-                QString::fromStdString(m_nativeInfo->orig_files().file_path(m_nativeIndexes[index])));
+    Q_ASSERT(index >= 0);
+    Q_ASSERT(index < m_nativeIndexes.size());
+    if ((index < 0) || (index >= m_nativeIndexes.size()))
+        return {};
+
+    return Path(m_nativeInfo->orig_files().file_path(m_nativeIndexes[index]));
 }
 
-QStringList TorrentInfo::filePaths() const
+PathList TorrentInfo::filePaths() const
 {
-    QStringList list;
+    PathList list;
     list.reserve(filesCount());
     for (int i = 0; i < filesCount(); ++i)
         list << filePath(i);
@@ -258,6 +250,11 @@ qlonglong TorrentInfo::fileSize(const int index) const
 {
     if (!isValid()) return -1;
 
+    Q_ASSERT(index >= 0);
+    Q_ASSERT(index < m_nativeIndexes.size());
+    if ((index < 0) || (index >= m_nativeIndexes.size()))
+        return -1;
+
     return m_nativeInfo->orig_files().file_size(m_nativeIndexes[index]);
 }
 
@@ -265,6 +262,11 @@ qlonglong TorrentInfo::fileOffset(const int index) const
 {
     if (!isValid()) return -1;
 
+    Q_ASSERT(index >= 0);
+    Q_ASSERT(index < m_nativeIndexes.size());
+    if ((index < 0) || (index >= m_nativeIndexes.size()))
+        return -1;
+
     return m_nativeInfo->orig_files().file_offset(m_nativeIndexes[index]);
 }
 
@@ -276,9 +278,8 @@ QVector<TrackerEntry> TorrentInfo::trackers() const
 
     QVector<TrackerEntry> ret;
     ret.reserve(static_cast<decltype(ret)::size_type>(trackers.size()));
-
     for (const lt::announce_entry &tracker : trackers)
-        ret.append({QString::fromStdString(tracker.url)});
+        ret.append({QString::fromStdString(tracker.url), tracker.tier});
 
     return ret;
 }
@@ -294,8 +295,12 @@ QVector<QUrl> TorrentInfo::urlSeeds() const
 
     for (const lt::web_seed_entry &webSeed : nativeWebSeeds)
     {
+#if LIBTORRENT_VERSION_NUM < 20100
         if (webSeed.type == lt::web_seed_entry::url_seed)
-            urlSeeds.append(QUrl(webSeed.url.c_str()));
+            urlSeeds.append(QUrl(QString::fromStdString(webSeed.url)));
+#else
+        urlSeeds.append(QUrl(QString::fromStdString(webSeed.url)));
+#endif
     }
 
     return urlSeeds;
@@ -312,15 +317,15 @@ QByteArray TorrentInfo::metadata() const
 #endif
 }
 
-QStringList TorrentInfo::filesForPiece(const int pieceIndex) const
+PathList TorrentInfo::filesForPiece(const int pieceIndex) const
 {
     // no checks here because fileIndicesForPiece() will return an empty list
     const QVector<int> fileIndices = fileIndicesForPiece(pieceIndex);
 
-    QStringList res;
+    PathList res;
     res.reserve(fileIndices.size());
-    std::transform(fileIndices.begin(), fileIndices.end(), std::back_inserter(res),
-        [this](int i) { return filePath(i); });
+    std::transform(fileIndices.begin(), fileIndices.end(), std::back_inserter(res)
+                   , [this](int i) { return filePath(i); });
 
     return res;
 }
@@ -359,15 +364,15 @@ QVector<QByteArray> TorrentInfo::pieceHashes() const
     return hashes;
 }
 
-TorrentInfo::PieceRange TorrentInfo::filePieces(const QString &file) const
+TorrentInfo::PieceRange TorrentInfo::filePieces(const Path &filePath) const
 {
     if (!isValid()) // if we do not check here the debug message will be printed, which would be not correct
         return {};
 
-    const int index = fileIndex(file);
+    const int index = fileIndex(filePath);
     if (index == -1)
     {
-        qDebug() << "Filename" << file << "was not found in torrent" << name();
+        qDebug() << "Filename" << filePath.toString() << "was not found in torrent" << name();
         return {};
     }
     return filePieces(index);
@@ -396,27 +401,19 @@ TorrentInfo::PieceRange TorrentInfo::filePieces(const int fileIndex) const
     return makeInterval(beginIdx, endIdx);
 }
 
-int TorrentInfo::fileIndex(const QString &fileName) const
+int TorrentInfo::fileIndex(const Path &filePath) const
 {
     // the check whether the object is valid is not needed here
     // because if filesCount() returns -1 the loop exits immediately
     for (int i = 0; i < filesCount(); ++i)
     {
-        if (fileName == filePath(i))
+        if (filePath == this->filePath(i))
             return i;
     }
 
     return -1;
 }
 
-TorrentContentLayout TorrentInfo::contentLayout() const
-{
-    if (!isValid())
-        return TorrentContentLayout::Original;
-
-    return detectContentLayout(filePaths());
-}
-
 std::shared_ptr<lt::torrent_info> TorrentInfo::nativeInfo() const
 {
     if (!isValid())
