@@ -31,13 +31,14 @@
 
 #include <QtGlobal>
 #include <QHash>
-#include <QNetworkAccessManager>
+#include <QNetworkProxy>
 #include <QObject>
 #include <QQueue>
 #include <QSet>
 
 #include "base/path.h"
 
+class QNetworkAccessManager;
 class QNetworkCookie;
 class QNetworkReply;
 class QSslError;
@@ -102,7 +103,7 @@ namespace Net
     struct DownloadResult
     {
         QString url;
-        DownloadStatus status;
+        DownloadStatus status = DownloadStatus::Failed;
         QString errorString;
         QByteArray data;
         Path filePath;
@@ -123,7 +124,9 @@ namespace Net
         void finished(const DownloadResult &result);
     };
 
-    class DownloadManager : public QObject
+    class DownloadHandlerImpl;
+
+    class DownloadManager final : public QObject
     {
         Q_OBJECT
         Q_DISABLE_COPY_MOVE(DownloadManager)
@@ -133,10 +136,10 @@ namespace Net
         static void freeInstance();
         static DownloadManager *instance();
 
-        DownloadHandler *download(const DownloadRequest &downloadRequest);
+        DownloadHandler *download(const DownloadRequest &downloadRequest, bool useProxy);
 
         template <typename Context, typename Func>
-        void download(const DownloadRequest &downloadRequest, Context context, Func &&slot);
+        void download(const DownloadRequest &downloadRequest, bool useProxy, Context context, Func &&slot);
 
         void registerSequentialService(const ServiceID &serviceID);
 
@@ -148,27 +151,29 @@ namespace Net
 
         static bool hasSupportedScheme(const QString &url);
 
-    private slots:
-        void ignoreSslErrors(QNetworkReply *, const QList<QSslError> &);
-
     private:
+        class NetworkCookieJar;
+
         explicit DownloadManager(QObject *parent = nullptr);
 
         void applyProxySettings();
-        void handleReplyFinished(const QNetworkReply *reply);
+        void handleDownloadFinished(DownloadHandlerImpl *finishedHandler);
+        void processRequest(DownloadHandlerImpl *downloadHandler);
 
         static DownloadManager *m_instance;
-        QNetworkAccessManager m_networkManager;
+        NetworkCookieJar *m_networkCookieJar = nullptr;
+        QNetworkAccessManager *m_networkManager = nullptr;
+        QNetworkProxy m_proxy;
 
         QSet<ServiceID> m_sequentialServices;
         QSet<ServiceID> m_busyServices;
-        QHash<ServiceID, QQueue<DownloadHandler *>> m_waitingJobs;
+        QHash<ServiceID, QQueue<DownloadHandlerImpl *>> m_waitingJobs;
     };
 
     template <typename Context, typename Func>
-    void DownloadManager::download(const DownloadRequest &downloadRequest, Context context, Func &&slot)
+    void DownloadManager::download(const DownloadRequest &downloadRequest, bool useProxy, Context context, Func &&slot)
     {
-        const DownloadHandler *handler = download(downloadRequest);
+        const DownloadHandler *handler = download(downloadRequest, useProxy);
         connect(handler, &DownloadHandler::finished, context, slot);
     }
 }
