@@ -60,7 +60,9 @@ public:
         StalledDownloading,
         Checking,
         Moving,
-        Errored
+        Errored,
+
+        _Count
     };
 
     // These mean any permutation, including no category / tag.
